Stubalyzer Changelog
====================

Development
-----------

`Commits <https://github.com/kialo/stubalyzer/compare/v0.5.0...master>`__

v0.5.0 - January 3rd 2022
-------------------------

`Commits <https://github.com/kialo/stubalyzer/compare/v0.4.0...v0.5.0>`__

-  Bump version: 0.4.0 → 0.5.0 - da4b12d
-  Ignore __path__ module symbol - ea19b5d
-  Upgrade mypy to 0.930 - c10f382
-  Fix release script to not build before version bump - 5e93f29

v0.4.0 - June 16th 2021
-----------------------

`Commits <https://github.com/kialo/stubalyzer/compare/v0.3.0...v0.4.0>`__

-  Bump version: 0.3.0 → 0.4.0 - 4e5d941
-  Fix dependency on bumpversion and update release script - 3f4b6ec
-  Store test results - 4e33840
-  Upgrade dependencies - 22accc2
-  Use newer python orb - befde4d
-  Simplify requirements - 5e47adc
-  Upgrade py and pygments - 32f1d5c
-  Fix commit hash in changelog - fcfbca9
-  Update CHANGELOG.rst - 11d2d2b

v0.3.0 - March 3rd 2020
-----------------------

`Commits <https://github.com/kialo/stubalyzer/compare/v0.2.0...v0.3.0>`__

-  Bump version: 0.2.0 → 0.3.0 - 2c5d33c
-  Fix release script and add wheel to dependencies - 87117a5
-  Fix docs. - 2751ff4
-  Enable pass through of "--include-private" to stubgen. - 7bb406a
-  Add release docs, release helper script, changelog - c945ad0

v0.2.0 - January 16th 2020
--------------------------

`Commits <https://github.com/kialo/stubalyzer/compare/v0.1.4...v0.2.0>`__

-  Bump version to 0.2.0 - 777132b
-  Upgrade dependencies - 5664fd7
-  Upgrade MyPy to 0.760 - 7c87f2b
-  Add silent mode (-s) - 42d3077

v0.1.4 - December 9th 2019
--------------------------

`Commits <https://github.com/kialo/stubalyzer/compare/v0.1.3...v0.1.4>`__

-  Bump version - 46a476a
-  Merge pull request #2 from kialo/mypy-upgrade - 8e36c05
-  Mypy 0.750 upgrade: re-format using black - 2b32ce2
-  Mypy 0.750 upgrade: update tests - d40f4bf
-  Mypy 0.750 upgrade: name methods -> properties - 4f03e0a

v0.1.3 - November 13th, 2019
----------------------------

`Commits <https://github.com/kialo/stubalyzer/compare/v0.1.2...v0.1.3>`__

-  Bump version and update readme. - ee518f8
-  Review comments. - 9c152a9

v0.1.2 - November 11th, 2019
----------------------------

`Commits <https://github.com/kialo/stubalyzer/compare/v0.1.1...v0.1.2>`__

-  Bump version. - 0f85056
-  Add newly added parameter to readme. - e79c04f
-  Compare parsed xml by hand, since stable attribute ordering
   is not enforceable. - 8d52922
-  Stable attribute order in xml report. - dfc4071
-  Compare with arbitrary paths. - d43083c
-  Stable ordering for xml output. - 24b3644
-  Add support to output a checkstyle formatted xml report. - 3e4f350
-  Remove more adverb from ignore message - 64249b8
-  Really fix linter - 529f7d0
-  Fix linter errors - 9584875
-  Add labels for mismatch output and change ignore message - 03d3ad8

v0.1.1 - November 7th, 2019
---------------------------

`Commits <https://github.com/kialo/stubalyzer/compare/v0.1.0...v0.1.1>`__

Bump version. - d3f889c
Update supported python versions. - 0e7346f

v0.1.0 - November 7th, 2019
---------------------------

`Commits <https://github.com/kialo/stubalyzer/compare/0.1a1...v0.1.0>`__
